This will load both rewarded and interstitial ads.
If a particular ad is already loaded, it will not load it again.
Also you do not have to call this method everytime. Ad is automatically loaded after being displayed.
Displays adUnitType ad from adNetwork. It will check if first ad it found from list is loaded,
it will be displayed if adNetwork is not mentioned otherwise it will load the ad.
Loads and immediately shows a Just-In-Time (JIT) AdMob Interstitial ad.
Call this when you want to display an interstitial ad on-demand (no preloading).
Loads and immediately shows a Just-In-Time (JIT) AdMob Rewarded ad with optional user prompt.
Handles showing loading overlay and success/error dialogs.